// ----------------------------------------------
// Implémentation de l'algorithme JeuduPendu
// Version : 3
// ----------------------------------------------
$(document).ready(function () {
    // 1. Création des variables exécuté au chargement de la page
    // --------------------------------------------------------
    // Tableau des mots à chercher (1a)
    var Tmots = ["poisson", "chien", "chat", "souris", "canari", "vache", "veau", "canard", "mouton", "cheval"];
    var motSecret; // Mot cherché (1b1) (extrait de Tmot[])
    var TReponse = []; // Tableau des lettres de la réponse (1c1)
    var nbLettresManquantes; // Nombre de lettres à chercher (1d1)
    var nbErreurs; // Nombre d'erreurs acceptées (1f1)
    var touche; // Touche sélectionnée par un clic de souris (1g1)
    var potence; // Position dans le graphe d'états modèlisant le dessin de la potence (1h1)
    var droitDeJouer; // Booléen : désactive le clavier (sauf Rejouer) si le jeu est fini (1i1)

    var canvas = document.getElementById("canvas");
    var context = canvas.getContext("2d");
    // --------------------------------------------------------
    // Fonctions
    var dessinerVisage = function (humeur, reduit) {
        context.strokeStyle = 'black';
        if (reduit) {
            context.clearRect(30, 70, 70, 70);
            context.lineWidth = 1;
            dessinerCercle(67, 52, 12, false)
            dessinerCercle(63, 48, 2, true);
            dessinerCercle(71, 48, 2, true);
            context.beginPath();
            context.arc(67, 64, 9, Math.PI / 180 * 310, Math.PI / 180 * 230, true);
            context.stroke();
        }
        else {
            context.lineWidth = 2;
            dessinerCercle(58, 105, 25, false)
            if (humeur === "joyeux") {
                dessinerCercle(68, 95, 5, true);
                dessinerCercle(48, 95, 5, true);
                context.beginPath();
                context.arc(58, 105, 18, Math.PI / 180 * 10, Math.PI / 180 * 170, false);
                context.stroke();
            } else {
                dessinerCercle(63, 95, 3, true);
                dessinerCercle(53, 95, 3, true);
                context.beginPath();
                context.arc(58, 130, 18, Math.PI / 180 * 310, Math.PI / 180 * 230, true);
                context.stroke();
            }
        }
    }
    var dessinerCercle = function (x, y, rayon, plein) {
        context.beginPath();
        context.arc(x, y, rayon, 0, 2 * Math.PI, false);
        if (plein)
            context.fill();
        else
            context.stroke();
    }
    var effacerCanevas = function () {
        context.clearRect(0, 0, canvas.width, canvas.height);
    }
    var resteEssais = function () {
        context.clearRect(0, 0, 115, 30);
        context.lineWidth = 1;
        context.font = "15px Arial";
        context.strokeText(nbErreurs + " essais", 10, 20);
    }
    var dessinerPotence = function () {
        switch (potence) {
            case 0:
                effacerCanevas();
                dessinerVisage("triste");
                context.fillRect(5, 195, 105, 10);
                potence++;
                break;
            case 1:
                context.fillRect(10, 30, 5, 165);
                potence++;
                break;
            case 2:
                context.fillRect(10, 30, 60, 5);
                potence++;
                break;
            case 3:
                context.lineWidth = 4;
                context.beginPath();
                context.moveTo(40, 32);
                context.lineTo(12, 70);
                context.stroke();
                potence++;
                break;
            case 4:
                context.fillRect(65, 30, 5, 10);
                potence++;
                break;
            case 5:
                dessinerVisage("triste", true);
                potence++;
                break;
            case 6:
                context.lineWidth = 2;
                context.beginPath();
                context.moveTo(67, 63);
                context.lineTo(67, 93);
                context.stroke();
                potence++;
                break;
            case 7:
                context.beginPath();
                context.moveTo(67, 78);
                context.lineTo(43, 64);
                context.stroke();
                potence++;
                break;
            case 8:
                context.beginPath();
                context.moveTo(67, 78);
                context.lineTo(91, 64);
                context.stroke();
                potence++;
                break;
            case 9:
                context.beginPath();
                context.moveTo(67, 93);
                context.lineTo(43, 107);
                context.stroke();
                potence++;
                break;
            case 10:
                context.beginPath();
                context.moveTo(67, 93);
                context.lineTo(91, 107);
                context.stroke();
                break;
        }
    }
    // Initialisation et Rejouer
    var initialisation = function () {
        $("#mot-cache").text("");
        $("#mot-cache").css("font-size", "50px");
        $(".touche").show(); // Affichage des touches du clavier (1j)
        // Choix aléatoire d'un mot dans le tableau (1b2)
        motSecret = Tmots[Math.floor(Math.random() * Tmots.length)];
        // Initialisation du tableau pour la réponse (1c2)
        TReponse.length = motSecret.length;
        for (var i = 0; i < motSecret.length; i++) {
            TReponse[i] = "-";
        }
        // Initialisations
        nbLettresManquantes = TReponse.length; // nombre de lettres à chercher (1d2)
        nbErreurs = nbLettresManquantes + 3; // nombre d'erreurs acceptées (1f2)
        touche = null; // touche sélectionnée par un clic de souris (1g2)
        potence = 0; // position dans le graphe d'états (1h2)
        droitDeJouer = true; // autorisation de jouer (1i2)

        // Instrumentation du code (A supprimer)
        console.log(motSecret, motSecret.length, TReponse.length, nbLettresManquantes, droitDeJouer, nbErreurs);
        // Premier affichage de la progression  (1e)
        $("#mot-cache").html(TReponse.join(" "));
    }
    // --------------------------------------------------------
    // 2. Partie de code exécutée au chargement de la page
    initialisation(); // premier jeu et rejouer
    dessinerVisage("joyeux", false);
    resteEssais();     // Affichage du nombre d'essais

    // 3. Boucle de jeu exécutée sur un évènement
    $(".touche").click(function () {
        if (droitDeJouer) {
            // Détection de la touche
            touche = $(this).text().toLocaleLowerCase(); // (2a)
            console.log(touche); // Instrumentation du code (A supprimer) 
            // si Touche Rejouer 
            if (touche === "rejouer") {
                initialisation();
                effacerCanevas(); dessinerVisage("joyeux", false);
                // Affichage du nombre d'essais
                resteEssais();
            }
            // sinon si toutes les lettres ne sont pas trouvées 
            else if (nbLettresManquantes > 0) { // Test de la réponse (2b)
                $(this).hide();
                var lettreTrouvee = false;
                for (var j = 0; j < motSecret.length; j++) {
                    if ((motSecret[j] === touche) && (TReponse[j] === "-")) {
                        console.log(j); // Instrumentation du code (A supprimer)
                        TReponse[j] = touche; // Copier la lettre à sa position dans le mot
                        nbLettresManquantes--;
                        console.log(touche, nbLettresManquantes); // Instrumentation du code (A supprimer)
                        // Affichage de la progression  (1e)
                        $("#mot-cache").html(TReponse.join(" "));
                        lettreTrouvee = true;
                    }
                }
                if (lettreTrouvee === false) {
                    dessinerPotence();
                    nbErreurs--;
                    if (nbErreurs === 0) {
                        resteEssais();
                        droitDeJouer = false; // Désactivation du clavier si le nombre de coups est atteint
                        // Message Vous avez perdu
                        $("#mot-cache").css("font-size", "18px");
                        $("#mot-cache").html("Vous avez <font color=\"red\">PERDU</font>, le mot était " + motSecret.toLocaleUpperCase());
                    }
                    else {
                        resteEssais();
                    }
                }

                // Message de félicitation (2c)
                if (nbLettresManquantes === 0) {
                    droitDeJouer = false; // Désactivation du clavier si le nombre de coups est atteint
                    for (var k = 0; k < motSecret.length; k++) {
                        TReponse[k] = TReponse[k].toLocaleUpperCase();
                    }
                    $("#mot-cache").css("font-size", "20px");
                    $("#mot-cache").text("Félicitation, le mot est bien " + TReponse.join(""));
                }
            }

            console.log(motSecret, motSecret.length, TReponse.length, nbLettresManquantes, droitDeJouer, nbErreurs); // Tests A supprimer
        } // fin droitDeJouer
        else { // Clavier inactif sauf touche "Rejouer"
            // Détection de la touche
            touche = $(this).text().toLocaleLowerCase(); // (2a)
            console.log(touche); // Instrumentation du code (A supprimer) 
            // si Touche Rejouer 
            if (touche === "rejouer") {
                initialisation();
                effacerCanevas(); dessinerVisage("joyeux", false);
                resteEssais();
            }
        }
    });
});

